@@ -18,26 +18,18 @@
 
 #include "kcm_pci.h"
 
-#include <QStringList>
 
 #include <KPluginFactory>
 #include <KPluginLoader>
 
 #include <kaboutdata.h>
-#include <kdialog.h>
-#include <kdebug.h>
+#include <QDebug>
 
-#include <QLayout>
-#include <QPainter>
 
-#include <QPixmap>
-#include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QTreeWidget>
 
-#include <klocale.h>
 #include <KLocalizedString>
-#include <kglobal.h>
 #include <kseparator.h>
 
 K_PLUGIN_FACTORY(KCMPciFactory,
@@ -78,7 +70,7 @@ KCMPci::~KCMPci() {
 }
 
 void KCMPci::load() {
-	kDebug() << "Loading PCI information..." << endl;
+	//qDebug() << "Loading PCI information..." << endl;
 	GetInfo_PCI(tree);
 
 	//Resize the column width to the maximum needed
