@@ -92,7 +92,7 @@ QString KcmTreeItem::data() const
 
 QString KcmTreeItem::category() const
 {
-    return m_module->property("X-KDE-KInfoCenter-Category").toString().trimmed();
+    return m_module->property(QStringLiteral("X-KDE-KInfoCenter-Category")).toString().trimmed();
 }
 
 KcmTreeItem::itemType KcmTreeItem::type() const
